The lino package — Lino docs 19.10.0 documentation

# The `lino` package

The `lino` package is the core package of every Lino application.

Lino is a high-level framework for writing desktop-like customized database applications based on Django and Sencha ExtJS. Lino applications are Django projects where the application developer does not need to write any URLconf, HTML nor CSS (more).

- This repository is considered an integral part of the Lino framework, which is documented as a whole in the Lino Book.

- Your feedback is welcome. Our community page explains how to contact us.

- API changes to this repository are logged at http://www.lino-framework.org/changes/